=======
History
=======

0.2.5 (01/10/2021)
------------------
* Added support for NOT logic operator
* Added For Loop 'NEXT' label
* Prevent constants from being re-assigned

0.2.2 (2021-04-20)
------------------

* Added support for constant and fixed 'Parser' has no attribute 'state' error 


0.2.1 (2021-04-13)
------------------

* Fixed bug in function calls.


0.1.9 (2021-04-09)
------------------

* First release on PyPI.
